aboutsummaryrefslogtreecommitdiff
path: root/object-file.h
diff options
context:
space:
mode:
Diffstat (limited to 'object-file.h')
-rw-r--r--object-file.h10
1 files changed, 2 insertions, 8 deletions
diff --git a/object-file.h b/object-file.h
index 1229d5f675..a62d0de394 100644
--- a/object-file.h
+++ b/object-file.h
@@ -202,16 +202,10 @@ struct odb_transaction;
/*
* Tell the object database to optimize for adding
* multiple objects. object_file_transaction_commit must be called
* to make new objects visible. If a transaction is already
* pending, NULL is returned.
*/
-struct odb_transaction *object_file_transaction_begin(struct odb_source *source);
-
-/*
- * Tell the object database to make any objects from the
- * current transaction visible.
- */
-void object_file_transaction_commit(struct odb_transaction *transaction);
+struct odb_transaction *odb_transaction_files_begin(struct odb_source *source);
#endif /* OBJECT_FILE_H */
@@ -202,16 +202,10 @@ struct odb_transaction;
/*
* Tell the object database to optimize for adding
- * multiple objects. object_file_transaction_commit must be called
+ * multiple objects. odb_transaction_files_commit must be called
* to make new objects visible. If a transaction is already
* pending, NULL is returned.